import SparcDashboard from './src/components/SparcDashboard.vue';
import "./tailwind/output.css"

import { defineAsyncComponent } from 'vue'
import mitt from 'mitt'
import { useGlobalVarsStore } from './src/stores/globalVars'



export function install(app) {
    if (install.installed) return;
	install.installed = true;
    // Register your component globally
    app.component('SparcDashboard', SparcDashboard);
  
    // Set up any dependencies here. Example with mitt:
    const emitter = mitt();
    app.config.globalProperties.$emitter = emitter;
  
    const componentMap = [
        'ImageSelector',
        'ImageViewer',
        'FlatmapViewer',
        'BiolucidaViewer'
    ]
    componentMap.forEach(comp=>{
        const asyncComponent = defineAsyncComponent(() => import(`./components/${comp}.vue`)); 
        app.component(comp, asyncComponent);
    })

    //add list of components to add componet drop down
    const globalVars = useGlobalVarsStore();
    globalVars.componentList = componentMap;

  }

  //for auto install -----------------------------------------------------------------------------------------------------------------
  const plugin = {
	install,
};
// Auto-install when vue is found (eg. in browser via <script> tag)
let GlobalVue = null;
if (typeof window !== 'undefined') {
	GlobalVue = window.Vue;
} else if (typeof global !== 'undefined') {
	GlobalVue = global.Vue;
}
if (GlobalVue) {
	GlobalVue.use(plugin);
}
//------------------------------------------------------------------------------------------------------------------------------------
  
export default SparcDashboard;